package cmdTemplate

import (
    "nexus-common/params"
    u "nexus-client/utils"
    g "nexus-client/globals"
    "github.com/google/uuid"
    "github.com/go-resty/resty/v2"
)

type Create struct {
    Name string
}

func (cmd *Create)GetName() string {
    return cmd.Name
}

func (cmd *Create)GetDesc() []string {
    return []string{
        "Creates a template from an existing VM.",
        "Requires TPL_CREATE user capability."}
}

func (cmd *Create)PrintUsage() {
    for _, desc := range cmd.GetDesc() {
        u.PrintlnErr(desc)
    }
    u.PrintlnErr("―――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――")
    u.PrintlnErr("USAGE: "+cmd.GetName()+" name access vmID")
    u.PrintlnErr("―――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――――")
    u.PrintlnErr("name      Name of the template to create.")
    u.PrintlnErr("access    Access type, either \"public\" or \"private\".")
    u.PrintlnErr("vmID      ID of the VM used to create the template.")
}

func (cmd *Create)Run(args []string) int {
    argc := len(args)
    if argc != 3 {
        cmd.PrintUsage()
        return 1
    }

    name := args[0]
    access := args[1]
    vmID, err := uuid.Parse(args[2])
    if err != nil {
        u.PrintlnErr(err)
    }

    resp, err := cmd.makeRequestForID(vmID, name, access)
    if err != nil {
        u.PrintlnErr("Error: "+err.Error())
        return 1
    }
    if resp.IsSuccess() {
        u.Println(resp)
        return 0
    } else {
        u.PrintlnErr("Error: "+resp.Status()+": "+resp.String())
        return 1
    }
}

func (cmd *Create)makeRequestForID(vmID uuid.UUID, name, access string) (*resty.Response, error) {
    client := g.GetInstance().Client
    host := g.GetInstance().Host

    p := &params.TplCreate{ vmID, name, access }
    resp, err := client.R().SetBody(p).Post(host+"/templates/vm")
    if err != nil {
        return nil, err
    }

    return resp, nil
}
